==> beast-propagation-shunt-2.6-20211222.054806-8-sources.jar: org/beast/propagation/shunt/ShuntAutoConfiguration.java <==
package org.beast.propagation.shunt;


import org.beast.propagation.PropagationAutoConfiguration;
import org.beast.propagation.context.CurrentContext;
import org.beast.propagation.shunt.propagation.CurrentShuntContext;
import org.springframework.boot.autoconfigure.AutoConfigureAfter;
import org.springframework.boot.autoconfigure.condition.ConditionalOnBean;
import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingBean;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.boot.context.properties.EnableConfigurationProperties;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

@Configuration
@ConditionalOnProperty(value = "micro.shunt.enabled", matchIfMissing = true)
@ConditionalOnBean(CurrentContext.class)
@AutoConfigureAfter(PropagationAutoConfiguration.class)
@EnableConfigurationProperties(ShuntProperties.class)
public class ShuntAutoConfiguration {


    @Bean
    @ConditionalOnMissingBean
    public CurrentShuntContext currentShuntContext(CurrentContext currentContext) {
        return new CurrentShuntContext(currentContext);
    }

    @Bean
    @ConditionalOnMissingBean
    public Shunt shunt(
//            @Value("${spring.application.name:default}") String serviceName,
            CurrentShuntContext currentShuntContext
    ) {
        Shunt.ShuntBuilder builder = Shunt.builder()
                .currentShuntContext(currentShuntContext);
        return builder.build();

    }
}

==> beast-propagation-shunt-2.7-20230117.022839-27-sources.jar: org/beast/propagation/shunt/ShuntAutoConfiguration.java <==
package org.beast.propagation.shunt;


import lombok.extern.slf4j.Slf4j;
import org.beast.propagation.PropagationAutoConfiguration;
import org.beast.propagation.context.CurrentContext;
import org.beast.propagation.shunt.propagation.CurrentShuntContext;
import org.springframework.boot.autoconfigure.AutoConfigureAfter;
import org.springframework.boot.autoconfigure.condition.ConditionalOnBean;
import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingBean;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.boot.context.properties.EnableConfigurationProperties;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

@Slf4j
@Configuration(proxyBeanMethods = false)
//@ConditionalOnProperty(value = "micro.shunt.enabled", matchIfMissing = true)
@ConditionalOnBean(CurrentContext.class)
@AutoConfigureAfter(PropagationAutoConfiguration.class)
@EnableConfigurationProperties(ShuntProperties.class)
public class ShuntAutoConfiguration {


    @Bean
    @ConditionalOnMissingBean
    public CurrentShuntContext currentShuntContext(CurrentContext currentContext) {
        return new CurrentShuntContext(currentContext);
    }

    @Bean
    @ConditionalOnMissingBean
    public Shunt shunt(
//            @Value("${spring.application.name:default}") String serviceName,
            CurrentShuntContext currentShuntContext
    ) {
        Shunt.ShuntBuilder builder = Shunt.builder()
                .currentShuntContext(currentShuntContext);
        return builder.build();

    }
}
